# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PipelineDefinitionArgs', 'PipelineDefinition']

@pulumi.input_type
class PipelineDefinitionArgs:
    def __init__(__self__, *,
                 pipeline_id: pulumi.Input[str],
                 pipeline_objects: pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]],
                 parameter_objects: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]]] = None,
                 parameter_values: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]]] = None):
        """
        The set of arguments for constructing a PipelineDefinition resource.
        :param pulumi.Input[str] pipeline_id: ID of the pipeline.
        :param pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]] pipeline_objects: Configuration block for the objects that define the pipeline. See below
        :param pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]] parameter_objects: Configuration block for the parameter objects used in the pipeline definition. See below
        :param pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]] parameter_values: Configuration block for the parameter values used in the pipeline definition. See below
        """
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        pulumi.set(__self__, "pipeline_objects", pipeline_objects)
        if parameter_objects is not None:
            pulumi.set(__self__, "parameter_objects", parameter_objects)
        if parameter_values is not None:
            pulumi.set(__self__, "parameter_values", parameter_values)

    @property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Input[str]:
        """
        ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "pipeline_id", value)

    @property
    @pulumi.getter(name="pipelineObjects")
    def pipeline_objects(self) -> pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]]:
        """
        Configuration block for the objects that define the pipeline. See below
        """
        return pulumi.get(self, "pipeline_objects")

    @pipeline_objects.setter
    def pipeline_objects(self, value: pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]]):
        pulumi.set(self, "pipeline_objects", value)

    @property
    @pulumi.getter(name="parameterObjects")
    def parameter_objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]]]:
        """
        Configuration block for the parameter objects used in the pipeline definition. See below
        """
        return pulumi.get(self, "parameter_objects")

    @parameter_objects.setter
    def parameter_objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]]]):
        pulumi.set(self, "parameter_objects", value)

    @property
    @pulumi.getter(name="parameterValues")
    def parameter_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]]]:
        """
        Configuration block for the parameter values used in the pipeline definition. See below
        """
        return pulumi.get(self, "parameter_values")

    @parameter_values.setter
    def parameter_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]]]):
        pulumi.set(self, "parameter_values", value)


@pulumi.input_type
class _PipelineDefinitionState:
    def __init__(__self__, *,
                 parameter_objects: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]]] = None,
                 parameter_values: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]]] = None,
                 pipeline_id: Optional[pulumi.Input[str]] = None,
                 pipeline_objects: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]]] = None):
        """
        Input properties used for looking up and filtering PipelineDefinition resources.
        :param pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]] parameter_objects: Configuration block for the parameter objects used in the pipeline definition. See below
        :param pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]] parameter_values: Configuration block for the parameter values used in the pipeline definition. See below
        :param pulumi.Input[str] pipeline_id: ID of the pipeline.
        :param pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]] pipeline_objects: Configuration block for the objects that define the pipeline. See below
        """
        if parameter_objects is not None:
            pulumi.set(__self__, "parameter_objects", parameter_objects)
        if parameter_values is not None:
            pulumi.set(__self__, "parameter_values", parameter_values)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)
        if pipeline_objects is not None:
            pulumi.set(__self__, "pipeline_objects", pipeline_objects)

    @property
    @pulumi.getter(name="parameterObjects")
    def parameter_objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]]]:
        """
        Configuration block for the parameter objects used in the pipeline definition. See below
        """
        return pulumi.get(self, "parameter_objects")

    @parameter_objects.setter
    def parameter_objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterObjectArgs']]]]):
        pulumi.set(self, "parameter_objects", value)

    @property
    @pulumi.getter(name="parameterValues")
    def parameter_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]]]:
        """
        Configuration block for the parameter values used in the pipeline definition. See below
        """
        return pulumi.get(self, "parameter_values")

    @parameter_values.setter
    def parameter_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionParameterValueArgs']]]]):
        pulumi.set(self, "parameter_values", value)

    @property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pipeline_id", value)

    @property
    @pulumi.getter(name="pipelineObjects")
    def pipeline_objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]]]:
        """
        Configuration block for the objects that define the pipeline. See below
        """
        return pulumi.get(self, "pipeline_objects")

    @pipeline_objects.setter
    def pipeline_objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineDefinitionPipelineObjectArgs']]]]):
        pulumi.set(self, "pipeline_objects", value)


class PipelineDefinition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 parameter_objects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterObjectArgs']]]]] = None,
                 parameter_values: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterValueArgs']]]]] = None,
                 pipeline_id: Optional[pulumi.Input[str]] = None,
                 pipeline_objects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionPipelineObjectArgs']]]]] = None,
                 __props__=None):
        """
        Provides a DataPipeline Pipeline Definition resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        default = aws.datapipeline.Pipeline("default")
        example = aws.datapipeline.PipelineDefinition("example",
            pipeline_id=default.id,
            pipeline_objects=[
                aws.datapipeline.PipelineDefinitionPipelineObjectArgs(
                    id="Default",
                    name="Default",
                    fields=[aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                        key="workerGroup",
                        string_value="workerGroup",
                    )],
                ),
                aws.datapipeline.PipelineDefinitionPipelineObjectArgs(
                    id="Schedule",
                    name="Schedule",
                    fields=[
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="startDateTime",
                            string_value="2012-12-12T00:00:00",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="type",
                            string_value="Schedule",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="period",
                            string_value="1 hour",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="endDateTime",
                            string_value="2012-12-21T18:00:00",
                        ),
                    ],
                ),
                aws.datapipeline.PipelineDefinitionPipelineObjectArgs(
                    id="SayHello",
                    name="SayHello",
                    fields=[
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="type",
                            string_value="ShellCommandActivity",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="command",
                            string_value="echo hello",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="parent",
                            string_value="Default",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="schedule",
                            string_value="Schedule",
                        ),
                    ],
                ),
            ])
        ```

        ## Import

        `aws_datapipeline_pipeline_definition` can be imported using the id, e.g.

        ```sh
         $ pulumi import aws:datapipeline/pipelineDefinition:PipelineDefinition example df-1234567890
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterObjectArgs']]]] parameter_objects: Configuration block for the parameter objects used in the pipeline definition. See below
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterValueArgs']]]] parameter_values: Configuration block for the parameter values used in the pipeline definition. See below
        :param pulumi.Input[str] pipeline_id: ID of the pipeline.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionPipelineObjectArgs']]]] pipeline_objects: Configuration block for the objects that define the pipeline. See below
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineDefinitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DataPipeline Pipeline Definition resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        default = aws.datapipeline.Pipeline("default")
        example = aws.datapipeline.PipelineDefinition("example",
            pipeline_id=default.id,
            pipeline_objects=[
                aws.datapipeline.PipelineDefinitionPipelineObjectArgs(
                    id="Default",
                    name="Default",
                    fields=[aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                        key="workerGroup",
                        string_value="workerGroup",
                    )],
                ),
                aws.datapipeline.PipelineDefinitionPipelineObjectArgs(
                    id="Schedule",
                    name="Schedule",
                    fields=[
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="startDateTime",
                            string_value="2012-12-12T00:00:00",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="type",
                            string_value="Schedule",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="period",
                            string_value="1 hour",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="endDateTime",
                            string_value="2012-12-21T18:00:00",
                        ),
                    ],
                ),
                aws.datapipeline.PipelineDefinitionPipelineObjectArgs(
                    id="SayHello",
                    name="SayHello",
                    fields=[
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="type",
                            string_value="ShellCommandActivity",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="command",
                            string_value="echo hello",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="parent",
                            string_value="Default",
                        ),
                        aws.datapipeline.PipelineDefinitionPipelineObjectFieldArgs(
                            key="schedule",
                            string_value="Schedule",
                        ),
                    ],
                ),
            ])
        ```

        ## Import

        `aws_datapipeline_pipeline_definition` can be imported using the id, e.g.

        ```sh
         $ pulumi import aws:datapipeline/pipelineDefinition:PipelineDefinition example df-1234567890
        ```

        :param str resource_name: The name of the resource.
        :param PipelineDefinitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineDefinitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 parameter_objects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterObjectArgs']]]]] = None,
                 parameter_values: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterValueArgs']]]]] = None,
                 pipeline_id: Optional[pulumi.Input[str]] = None,
                 pipeline_objects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionPipelineObjectArgs']]]]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineDefinitionArgs.__new__(PipelineDefinitionArgs)

            __props__.__dict__["parameter_objects"] = parameter_objects
            __props__.__dict__["parameter_values"] = parameter_values
            if pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_id'")
            __props__.__dict__["pipeline_id"] = pipeline_id
            if pipeline_objects is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_objects'")
            __props__.__dict__["pipeline_objects"] = pipeline_objects
        super(PipelineDefinition, __self__).__init__(
            'aws:datapipeline/pipelineDefinition:PipelineDefinition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            parameter_objects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterObjectArgs']]]]] = None,
            parameter_values: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterValueArgs']]]]] = None,
            pipeline_id: Optional[pulumi.Input[str]] = None,
            pipeline_objects: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionPipelineObjectArgs']]]]] = None) -> 'PipelineDefinition':
        """
        Get an existing PipelineDefinition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterObjectArgs']]]] parameter_objects: Configuration block for the parameter objects used in the pipeline definition. See below
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionParameterValueArgs']]]] parameter_values: Configuration block for the parameter values used in the pipeline definition. See below
        :param pulumi.Input[str] pipeline_id: ID of the pipeline.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PipelineDefinitionPipelineObjectArgs']]]] pipeline_objects: Configuration block for the objects that define the pipeline. See below
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineDefinitionState.__new__(_PipelineDefinitionState)

        __props__.__dict__["parameter_objects"] = parameter_objects
        __props__.__dict__["parameter_values"] = parameter_values
        __props__.__dict__["pipeline_id"] = pipeline_id
        __props__.__dict__["pipeline_objects"] = pipeline_objects
        return PipelineDefinition(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="parameterObjects")
    def parameter_objects(self) -> pulumi.Output[Optional[Sequence['outputs.PipelineDefinitionParameterObject']]]:
        """
        Configuration block for the parameter objects used in the pipeline definition. See below
        """
        return pulumi.get(self, "parameter_objects")

    @property
    @pulumi.getter(name="parameterValues")
    def parameter_values(self) -> pulumi.Output[Optional[Sequence['outputs.PipelineDefinitionParameterValue']]]:
        """
        Configuration block for the parameter values used in the pipeline definition. See below
        """
        return pulumi.get(self, "parameter_values")

    @property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Output[str]:
        """
        ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @property
    @pulumi.getter(name="pipelineObjects")
    def pipeline_objects(self) -> pulumi.Output[Sequence['outputs.PipelineDefinitionPipelineObject']]:
        """
        Configuration block for the objects that define the pipeline. See below
        """
        return pulumi.get(self, "pipeline_objects")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['PlatformApplicationArgs', 'PlatformApplication']

@pulumi.input_type
class PlatformApplicationArgs:
    def __init__(__self__, *,
                 platform: pulumi.Input[str],
                 platform_credential: pulumi.Input[str],
                 event_delivery_failure_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_created_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_deleted_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_updated_topic_arn: Optional[pulumi.Input[str]] = None,
                 failure_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 platform_principal: Optional[pulumi.Input[str]] = None,
                 success_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 success_feedback_sample_rate: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a PlatformApplication resource.
        :param pulumi.Input[str] platform: The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        :param pulumi.Input[str] platform_credential: Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] event_delivery_failure_topic_arn: The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        :param pulumi.Input[str] event_endpoint_created_topic_arn: The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        :param pulumi.Input[str] event_endpoint_deleted_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        :param pulumi.Input[str] event_endpoint_updated_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        :param pulumi.Input[str] failure_feedback_role_arn: The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] name: The friendly name for the SNS platform application
        :param pulumi.Input[str] platform_principal: Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] success_feedback_role_arn: The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] success_feedback_sample_rate: The sample rate percentage (0-100) of successfully delivered messages.
        """
        pulumi.set(__self__, "platform", platform)
        pulumi.set(__self__, "platform_credential", platform_credential)
        if event_delivery_failure_topic_arn is not None:
            pulumi.set(__self__, "event_delivery_failure_topic_arn", event_delivery_failure_topic_arn)
        if event_endpoint_created_topic_arn is not None:
            pulumi.set(__self__, "event_endpoint_created_topic_arn", event_endpoint_created_topic_arn)
        if event_endpoint_deleted_topic_arn is not None:
            pulumi.set(__self__, "event_endpoint_deleted_topic_arn", event_endpoint_deleted_topic_arn)
        if event_endpoint_updated_topic_arn is not None:
            pulumi.set(__self__, "event_endpoint_updated_topic_arn", event_endpoint_updated_topic_arn)
        if failure_feedback_role_arn is not None:
            pulumi.set(__self__, "failure_feedback_role_arn", failure_feedback_role_arn)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if platform_principal is not None:
            pulumi.set(__self__, "platform_principal", platform_principal)
        if success_feedback_role_arn is not None:
            pulumi.set(__self__, "success_feedback_role_arn", success_feedback_role_arn)
        if success_feedback_sample_rate is not None:
            pulumi.set(__self__, "success_feedback_sample_rate", success_feedback_sample_rate)

    @property
    @pulumi.getter
    def platform(self) -> pulumi.Input[str]:
        """
        The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: pulumi.Input[str]):
        pulumi.set(self, "platform", value)

    @property
    @pulumi.getter(name="platformCredential")
    def platform_credential(self) -> pulumi.Input[str]:
        """
        Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        """
        return pulumi.get(self, "platform_credential")

    @platform_credential.setter
    def platform_credential(self, value: pulumi.Input[str]):
        pulumi.set(self, "platform_credential", value)

    @property
    @pulumi.getter(name="eventDeliveryFailureTopicArn")
    def event_delivery_failure_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        """
        return pulumi.get(self, "event_delivery_failure_topic_arn")

    @event_delivery_failure_topic_arn.setter
    def event_delivery_failure_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_delivery_failure_topic_arn", value)

    @property
    @pulumi.getter(name="eventEndpointCreatedTopicArn")
    def event_endpoint_created_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        """
        return pulumi.get(self, "event_endpoint_created_topic_arn")

    @event_endpoint_created_topic_arn.setter
    def event_endpoint_created_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_endpoint_created_topic_arn", value)

    @property
    @pulumi.getter(name="eventEndpointDeletedTopicArn")
    def event_endpoint_deleted_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        """
        return pulumi.get(self, "event_endpoint_deleted_topic_arn")

    @event_endpoint_deleted_topic_arn.setter
    def event_endpoint_deleted_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_endpoint_deleted_topic_arn", value)

    @property
    @pulumi.getter(name="eventEndpointUpdatedTopicArn")
    def event_endpoint_updated_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        """
        return pulumi.get(self, "event_endpoint_updated_topic_arn")

    @event_endpoint_updated_topic_arn.setter
    def event_endpoint_updated_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_endpoint_updated_topic_arn", value)

    @property
    @pulumi.getter(name="failureFeedbackRoleArn")
    def failure_feedback_role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        """
        return pulumi.get(self, "failure_feedback_role_arn")

    @failure_feedback_role_arn.setter
    def failure_feedback_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failure_feedback_role_arn", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The friendly name for the SNS platform application
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="platformPrincipal")
    def platform_principal(self) -> Optional[pulumi.Input[str]]:
        """
        Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        """
        return pulumi.get(self, "platform_principal")

    @platform_principal.setter
    def platform_principal(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_principal", value)

    @property
    @pulumi.getter(name="successFeedbackRoleArn")
    def success_feedback_role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        """
        return pulumi.get(self, "success_feedback_role_arn")

    @success_feedback_role_arn.setter
    def success_feedback_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "success_feedback_role_arn", value)

    @property
    @pulumi.getter(name="successFeedbackSampleRate")
    def success_feedback_sample_rate(self) -> Optional[pulumi.Input[str]]:
        """
        The sample rate percentage (0-100) of successfully delivered messages.
        """
        return pulumi.get(self, "success_feedback_sample_rate")

    @success_feedback_sample_rate.setter
    def success_feedback_sample_rate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "success_feedback_sample_rate", value)


@pulumi.input_type
class _PlatformApplicationState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 event_delivery_failure_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_created_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_deleted_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_updated_topic_arn: Optional[pulumi.Input[str]] = None,
                 failure_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 platform_credential: Optional[pulumi.Input[str]] = None,
                 platform_principal: Optional[pulumi.Input[str]] = None,
                 success_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 success_feedback_sample_rate: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PlatformApplication resources.
        :param pulumi.Input[str] arn: The ARN of the SNS platform application
        :param pulumi.Input[str] event_delivery_failure_topic_arn: The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        :param pulumi.Input[str] event_endpoint_created_topic_arn: The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        :param pulumi.Input[str] event_endpoint_deleted_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        :param pulumi.Input[str] event_endpoint_updated_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        :param pulumi.Input[str] failure_feedback_role_arn: The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] name: The friendly name for the SNS platform application
        :param pulumi.Input[str] platform: The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        :param pulumi.Input[str] platform_credential: Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] platform_principal: Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] success_feedback_role_arn: The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] success_feedback_sample_rate: The sample rate percentage (0-100) of successfully delivered messages.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if event_delivery_failure_topic_arn is not None:
            pulumi.set(__self__, "event_delivery_failure_topic_arn", event_delivery_failure_topic_arn)
        if event_endpoint_created_topic_arn is not None:
            pulumi.set(__self__, "event_endpoint_created_topic_arn", event_endpoint_created_topic_arn)
        if event_endpoint_deleted_topic_arn is not None:
            pulumi.set(__self__, "event_endpoint_deleted_topic_arn", event_endpoint_deleted_topic_arn)
        if event_endpoint_updated_topic_arn is not None:
            pulumi.set(__self__, "event_endpoint_updated_topic_arn", event_endpoint_updated_topic_arn)
        if failure_feedback_role_arn is not None:
            pulumi.set(__self__, "failure_feedback_role_arn", failure_feedback_role_arn)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if platform_credential is not None:
            pulumi.set(__self__, "platform_credential", platform_credential)
        if platform_principal is not None:
            pulumi.set(__self__, "platform_principal", platform_principal)
        if success_feedback_role_arn is not None:
            pulumi.set(__self__, "success_feedback_role_arn", success_feedback_role_arn)
        if success_feedback_sample_rate is not None:
            pulumi.set(__self__, "success_feedback_sample_rate", success_feedback_sample_rate)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS platform application
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="eventDeliveryFailureTopicArn")
    def event_delivery_failure_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        """
        return pulumi.get(self, "event_delivery_failure_topic_arn")

    @event_delivery_failure_topic_arn.setter
    def event_delivery_failure_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_delivery_failure_topic_arn", value)

    @property
    @pulumi.getter(name="eventEndpointCreatedTopicArn")
    def event_endpoint_created_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        """
        return pulumi.get(self, "event_endpoint_created_topic_arn")

    @event_endpoint_created_topic_arn.setter
    def event_endpoint_created_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_endpoint_created_topic_arn", value)

    @property
    @pulumi.getter(name="eventEndpointDeletedTopicArn")
    def event_endpoint_deleted_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        """
        return pulumi.get(self, "event_endpoint_deleted_topic_arn")

    @event_endpoint_deleted_topic_arn.setter
    def event_endpoint_deleted_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_endpoint_deleted_topic_arn", value)

    @property
    @pulumi.getter(name="eventEndpointUpdatedTopicArn")
    def event_endpoint_updated_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        """
        return pulumi.get(self, "event_endpoint_updated_topic_arn")

    @event_endpoint_updated_topic_arn.setter
    def event_endpoint_updated_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "event_endpoint_updated_topic_arn", value)

    @property
    @pulumi.getter(name="failureFeedbackRoleArn")
    def failure_feedback_role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        """
        return pulumi.get(self, "failure_feedback_role_arn")

    @failure_feedback_role_arn.setter
    def failure_feedback_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "failure_feedback_role_arn", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The friendly name for the SNS platform application
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[str]]:
        """
        The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform", value)

    @property
    @pulumi.getter(name="platformCredential")
    def platform_credential(self) -> Optional[pulumi.Input[str]]:
        """
        Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        """
        return pulumi.get(self, "platform_credential")

    @platform_credential.setter
    def platform_credential(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_credential", value)

    @property
    @pulumi.getter(name="platformPrincipal")
    def platform_principal(self) -> Optional[pulumi.Input[str]]:
        """
        Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        """
        return pulumi.get(self, "platform_principal")

    @platform_principal.setter
    def platform_principal(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_principal", value)

    @property
    @pulumi.getter(name="successFeedbackRoleArn")
    def success_feedback_role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        """
        return pulumi.get(self, "success_feedback_role_arn")

    @success_feedback_role_arn.setter
    def success_feedback_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "success_feedback_role_arn", value)

    @property
    @pulumi.getter(name="successFeedbackSampleRate")
    def success_feedback_sample_rate(self) -> Optional[pulumi.Input[str]]:
        """
        The sample rate percentage (0-100) of successfully delivered messages.
        """
        return pulumi.get(self, "success_feedback_sample_rate")

    @success_feedback_sample_rate.setter
    def success_feedback_sample_rate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "success_feedback_sample_rate", value)


class PlatformApplication(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_delivery_failure_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_created_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_deleted_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_updated_topic_arn: Optional[pulumi.Input[str]] = None,
                 failure_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 platform_credential: Optional[pulumi.Input[str]] = None,
                 platform_principal: Optional[pulumi.Input[str]] = None,
                 success_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 success_feedback_sample_rate: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides an SNS platform application resource

        ## Example Usage
        ### Apple Push Notification Service (APNS)

        ```python
        import pulumi
        import pulumi_aws as aws

        apns_application = aws.sns.PlatformApplication("apnsApplication",
            platform="APNS",
            platform_credential="<APNS PRIVATE KEY>",
            platform_principal="<APNS CERTIFICATE>")
        ```
        ### Google Cloud Messaging (GCM)

        ```python
        import pulumi
        import pulumi_aws as aws

        gcm_application = aws.sns.PlatformApplication("gcmApplication",
            platform="GCM",
            platform_credential="<GCM API KEY>")
        ```

        ## Import

        SNS platform applications can be imported using the ARN, e.g.,

        ```sh
         $ pulumi import aws:sns/platformApplication:PlatformApplication gcm_application arn:aws:sns:us-west-2:0123456789012:app/GCM/gcm_application
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] event_delivery_failure_topic_arn: The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        :param pulumi.Input[str] event_endpoint_created_topic_arn: The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        :param pulumi.Input[str] event_endpoint_deleted_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        :param pulumi.Input[str] event_endpoint_updated_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        :param pulumi.Input[str] failure_feedback_role_arn: The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] name: The friendly name for the SNS platform application
        :param pulumi.Input[str] platform: The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        :param pulumi.Input[str] platform_credential: Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] platform_principal: Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] success_feedback_role_arn: The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] success_feedback_sample_rate: The sample rate percentage (0-100) of successfully delivered messages.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PlatformApplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an SNS platform application resource

        ## Example Usage
        ### Apple Push Notification Service (APNS)

        ```python
        import pulumi
        import pulumi_aws as aws

        apns_application = aws.sns.PlatformApplication("apnsApplication",
            platform="APNS",
            platform_credential="<APNS PRIVATE KEY>",
            platform_principal="<APNS CERTIFICATE>")
        ```
        ### Google Cloud Messaging (GCM)

        ```python
        import pulumi
        import pulumi_aws as aws

        gcm_application = aws.sns.PlatformApplication("gcmApplication",
            platform="GCM",
            platform_credential="<GCM API KEY>")
        ```

        ## Import

        SNS platform applications can be imported using the ARN, e.g.,

        ```sh
         $ pulumi import aws:sns/platformApplication:PlatformApplication gcm_application arn:aws:sns:us-west-2:0123456789012:app/GCM/gcm_application
        ```

        :param str resource_name: The name of the resource.
        :param PlatformApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PlatformApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 event_delivery_failure_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_created_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_deleted_topic_arn: Optional[pulumi.Input[str]] = None,
                 event_endpoint_updated_topic_arn: Optional[pulumi.Input[str]] = None,
                 failure_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 platform: Optional[pulumi.Input[str]] = None,
                 platform_credential: Optional[pulumi.Input[str]] = None,
                 platform_principal: Optional[pulumi.Input[str]] = None,
                 success_feedback_role_arn: Optional[pulumi.Input[str]] = None,
                 success_feedback_sample_rate: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PlatformApplicationArgs.__new__(PlatformApplicationArgs)

            __props__.__dict__["event_delivery_failure_topic_arn"] = event_delivery_failure_topic_arn
            __props__.__dict__["event_endpoint_created_topic_arn"] = event_endpoint_created_topic_arn
            __props__.__dict__["event_endpoint_deleted_topic_arn"] = event_endpoint_deleted_topic_arn
            __props__.__dict__["event_endpoint_updated_topic_arn"] = event_endpoint_updated_topic_arn
            __props__.__dict__["failure_feedback_role_arn"] = failure_feedback_role_arn
            __props__.__dict__["name"] = name
            if platform is None and not opts.urn:
                raise TypeError("Missing required property 'platform'")
            __props__.__dict__["platform"] = platform
            if platform_credential is None and not opts.urn:
                raise TypeError("Missing required property 'platform_credential'")
            __props__.__dict__["platform_credential"] = platform_credential
            __props__.__dict__["platform_principal"] = platform_principal
            __props__.__dict__["success_feedback_role_arn"] = success_feedback_role_arn
            __props__.__dict__["success_feedback_sample_rate"] = success_feedback_sample_rate
            __props__.__dict__["arn"] = None
        super(PlatformApplication, __self__).__init__(
            'aws:sns/platformApplication:PlatformApplication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            event_delivery_failure_topic_arn: Optional[pulumi.Input[str]] = None,
            event_endpoint_created_topic_arn: Optional[pulumi.Input[str]] = None,
            event_endpoint_deleted_topic_arn: Optional[pulumi.Input[str]] = None,
            event_endpoint_updated_topic_arn: Optional[pulumi.Input[str]] = None,
            failure_feedback_role_arn: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            platform: Optional[pulumi.Input[str]] = None,
            platform_credential: Optional[pulumi.Input[str]] = None,
            platform_principal: Optional[pulumi.Input[str]] = None,
            success_feedback_role_arn: Optional[pulumi.Input[str]] = None,
            success_feedback_sample_rate: Optional[pulumi.Input[str]] = None) -> 'PlatformApplication':
        """
        Get an existing PlatformApplication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The ARN of the SNS platform application
        :param pulumi.Input[str] event_delivery_failure_topic_arn: The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        :param pulumi.Input[str] event_endpoint_created_topic_arn: The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        :param pulumi.Input[str] event_endpoint_deleted_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        :param pulumi.Input[str] event_endpoint_updated_topic_arn: The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        :param pulumi.Input[str] failure_feedback_role_arn: The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] name: The friendly name for the SNS platform application
        :param pulumi.Input[str] platform: The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        :param pulumi.Input[str] platform_credential: Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] platform_principal: Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        :param pulumi.Input[str] success_feedback_role_arn: The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        :param pulumi.Input[str] success_feedback_sample_rate: The sample rate percentage (0-100) of successfully delivered messages.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PlatformApplicationState.__new__(_PlatformApplicationState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["event_delivery_failure_topic_arn"] = event_delivery_failure_topic_arn
        __props__.__dict__["event_endpoint_created_topic_arn"] = event_endpoint_created_topic_arn
        __props__.__dict__["event_endpoint_deleted_topic_arn"] = event_endpoint_deleted_topic_arn
        __props__.__dict__["event_endpoint_updated_topic_arn"] = event_endpoint_updated_topic_arn
        __props__.__dict__["failure_feedback_role_arn"] = failure_feedback_role_arn
        __props__.__dict__["name"] = name
        __props__.__dict__["platform"] = platform
        __props__.__dict__["platform_credential"] = platform_credential
        __props__.__dict__["platform_principal"] = platform_principal
        __props__.__dict__["success_feedback_role_arn"] = success_feedback_role_arn
        __props__.__dict__["success_feedback_sample_rate"] = success_feedback_sample_rate
        return PlatformApplication(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        The ARN of the SNS platform application
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="eventDeliveryFailureTopicArn")
    def event_delivery_failure_topic_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The ARN of the SNS Topic triggered when a delivery to any of the platform endpoints associated with your platform application encounters a permanent failure.
        """
        return pulumi.get(self, "event_delivery_failure_topic_arn")

    @property
    @pulumi.getter(name="eventEndpointCreatedTopicArn")
    def event_endpoint_created_topic_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The ARN of the SNS Topic triggered when a new platform endpoint is added to your platform application.
        """
        return pulumi.get(self, "event_endpoint_created_topic_arn")

    @property
    @pulumi.getter(name="eventEndpointDeletedTopicArn")
    def event_endpoint_deleted_topic_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The ARN of the SNS Topic triggered when an existing platform endpoint is deleted from your platform application.
        """
        return pulumi.get(self, "event_endpoint_deleted_topic_arn")

    @property
    @pulumi.getter(name="eventEndpointUpdatedTopicArn")
    def event_endpoint_updated_topic_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The ARN of the SNS Topic triggered when an existing platform endpoint is changed from your platform application.
        """
        return pulumi.get(self, "event_endpoint_updated_topic_arn")

    @property
    @pulumi.getter(name="failureFeedbackRoleArn")
    def failure_feedback_role_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The IAM role ARN permitted to receive failure feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        """
        return pulumi.get(self, "failure_feedback_role_arn")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The friendly name for the SNS platform application
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def platform(self) -> pulumi.Output[str]:
        """
        The platform that the app is registered with. See [Platform](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for supported platforms.
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="platformCredential")
    def platform_credential(self) -> pulumi.Output[str]:
        """
        Application Platform credential. See [Credential](http://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-register.html) for type of credential required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        """
        return pulumi.get(self, "platform_credential")

    @property
    @pulumi.getter(name="platformPrincipal")
    def platform_principal(self) -> pulumi.Output[Optional[str]]:
        """
        Application Platform principal. See [Principal](http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html) for type of principal required for platform. The value of this attribute when stored into the state is only a hash of the real value, so therefore it is not practical to use this as an attribute for other resources.
        """
        return pulumi.get(self, "platform_principal")

    @property
    @pulumi.getter(name="successFeedbackRoleArn")
    def success_feedback_role_arn(self) -> pulumi.Output[Optional[str]]:
        """
        The IAM role ARN permitted to receive success feedback for this application and give SNS write access to use CloudWatch logs on your behalf.
        """
        return pulumi.get(self, "success_feedback_role_arn")

    @property
    @pulumi.getter(name="successFeedbackSampleRate")
    def success_feedback_sample_rate(self) -> pulumi.Output[Optional[str]]:
        """
        The sample rate percentage (0-100) of successfully delivered messages.
        """
        return pulumi.get(self, "success_feedback_sample_rate")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ConnectionAssociationArgs', 'ConnectionAssociation']

@pulumi.input_type
class ConnectionAssociationArgs:
    def __init__(__self__, *,
                 connection_id: pulumi.Input[str],
                 lag_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ConnectionAssociation resource.
        :param pulumi.Input[str] connection_id: The ID of the connection.
        :param pulumi.Input[str] lag_id: The ID of the LAG with which to associate the connection.
        """
        pulumi.set(__self__, "connection_id", connection_id)
        pulumi.set(__self__, "lag_id", lag_id)

    @property
    @pulumi.getter(name="connectionId")
    def connection_id(self) -> pulumi.Input[str]:
        """
        The ID of the connection.
        """
        return pulumi.get(self, "connection_id")

    @connection_id.setter
    def connection_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "connection_id", value)

    @property
    @pulumi.getter(name="lagId")
    def lag_id(self) -> pulumi.Input[str]:
        """
        The ID of the LAG with which to associate the connection.
        """
        return pulumi.get(self, "lag_id")

    @lag_id.setter
    def lag_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "lag_id", value)


@pulumi.input_type
class _ConnectionAssociationState:
    def __init__(__self__, *,
                 connection_id: Optional[pulumi.Input[str]] = None,
                 lag_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ConnectionAssociation resources.
        :param pulumi.Input[str] connection_id: The ID of the connection.
        :param pulumi.Input[str] lag_id: The ID of the LAG with which to associate the connection.
        """
        if connection_id is not None:
            pulumi.set(__self__, "connection_id", connection_id)
        if lag_id is not None:
            pulumi.set(__self__, "lag_id", lag_id)

    @property
    @pulumi.getter(name="connectionId")
    def connection_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the connection.
        """
        return pulumi.get(self, "connection_id")

    @connection_id.setter
    def connection_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_id", value)

    @property
    @pulumi.getter(name="lagId")
    def lag_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the LAG with which to associate the connection.
        """
        return pulumi.get(self, "lag_id")

    @lag_id.setter
    def lag_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lag_id", value)


class ConnectionAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_id: Optional[pulumi.Input[str]] = None,
                 lag_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Associates a Direct Connect Connection with a LAG.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_connection = aws.directconnect.Connection("exampleConnection",
            bandwidth="1Gbps",
            location="EqSe2-EQ")
        example_link_aggregation_group = aws.directconnect.LinkAggregationGroup("exampleLinkAggregationGroup",
            connections_bandwidth="1Gbps",
            location="EqSe2-EQ")
        example_connection_association = aws.directconnect.ConnectionAssociation("exampleConnectionAssociation",
            connection_id=example_connection.id,
            lag_id=example_link_aggregation_group.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_id: The ID of the connection.
        :param pulumi.Input[str] lag_id: The ID of the LAG with which to associate the connection.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Associates a Direct Connect Connection with a LAG.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_connection = aws.directconnect.Connection("exampleConnection",
            bandwidth="1Gbps",
            location="EqSe2-EQ")
        example_link_aggregation_group = aws.directconnect.LinkAggregationGroup("exampleLinkAggregationGroup",
            connections_bandwidth="1Gbps",
            location="EqSe2-EQ")
        example_connection_association = aws.directconnect.ConnectionAssociation("exampleConnectionAssociation",
            connection_id=example_connection.id,
            lag_id=example_link_aggregation_group.id)
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_id: Optional[pulumi.Input[str]] = None,
                 lag_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionAssociationArgs.__new__(ConnectionAssociationArgs)

            if connection_id is None and not opts.urn:
                raise TypeError("Missing required property 'connection_id'")
            __props__.__dict__["connection_id"] = connection_id
            if lag_id is None and not opts.urn:
                raise TypeError("Missing required property 'lag_id'")
            __props__.__dict__["lag_id"] = lag_id
        super(ConnectionAssociation, __self__).__init__(
            'aws:directconnect/connectionAssociation:ConnectionAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_id: Optional[pulumi.Input[str]] = None,
            lag_id: Optional[pulumi.Input[str]] = None) -> 'ConnectionAssociation':
        """
        Get an existing ConnectionAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_id: The ID of the connection.
        :param pulumi.Input[str] lag_id: The ID of the LAG with which to associate the connection.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionAssociationState.__new__(_ConnectionAssociationState)

        __props__.__dict__["connection_id"] = connection_id
        __props__.__dict__["lag_id"] = lag_id
        return ConnectionAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionId")
    def connection_id(self) -> pulumi.Output[str]:
        """
        The ID of the connection.
        """
        return pulumi.get(self, "connection_id")

    @property
    @pulumi.getter(name="lagId")
    def lag_id(self) -> pulumi.Output[str]:
        """
        The ID of the LAG with which to associate the connection.
        """
        return pulumi.get(self, "lag_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DefaultRouteTableArgs', 'DefaultRouteTable']

@pulumi.input_type
class DefaultRouteTableArgs:
    def __init__(__self__, *,
                 default_route_table_id: pulumi.Input[str],
                 propagating_vgws: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a DefaultRouteTable resource.
        :param pulumi.Input[str] default_route_table_id: ID of the default route table.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] propagating_vgws: List of virtual gateways for propagation.
        :param pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]] routes: Set of objects. Detailed below
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        pulumi.set(__self__, "default_route_table_id", default_route_table_id)
        if propagating_vgws is not None:
            pulumi.set(__self__, "propagating_vgws", propagating_vgws)
        if routes is not None:
            pulumi.set(__self__, "routes", routes)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="defaultRouteTableId")
    def default_route_table_id(self) -> pulumi.Input[str]:
        """
        ID of the default route table.
        """
        return pulumi.get(self, "default_route_table_id")

    @default_route_table_id.setter
    def default_route_table_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "default_route_table_id", value)

    @property
    @pulumi.getter(name="propagatingVgws")
    def propagating_vgws(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of virtual gateways for propagation.
        """
        return pulumi.get(self, "propagating_vgws")

    @propagating_vgws.setter
    def propagating_vgws(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "propagating_vgws", value)

    @property
    @pulumi.getter
    def routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]]]:
        """
        Set of objects. Detailed below
        """
        return pulumi.get(self, "routes")

    @routes.setter
    def routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]]]):
        pulumi.set(self, "routes", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _DefaultRouteTableState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 default_route_table_id: Optional[pulumi.Input[str]] = None,
                 owner_id: Optional[pulumi.Input[str]] = None,
                 propagating_vgws: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DefaultRouteTable resources.
        :param pulumi.Input[str] arn: The ARN of the route table.
        :param pulumi.Input[str] default_route_table_id: ID of the default route table.
        :param pulumi.Input[str] owner_id: ID of the AWS account that owns the route table.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] propagating_vgws: List of virtual gateways for propagation.
        :param pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]] routes: Set of objects. Detailed below
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider .
        :param pulumi.Input[str] vpc_id: ID of the VPC.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if default_route_table_id is not None:
            pulumi.set(__self__, "default_route_table_id", default_route_table_id)
        if owner_id is not None:
            pulumi.set(__self__, "owner_id", owner_id)
        if propagating_vgws is not None:
            pulumi.set(__self__, "propagating_vgws", propagating_vgws)
        if routes is not None:
            pulumi.set(__self__, "routes", routes)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_all is not None:
            pulumi.set(__self__, "tags_all", tags_all)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the route table.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="defaultRouteTableId")
    def default_route_table_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the default route table.
        """
        return pulumi.get(self, "default_route_table_id")

    @default_route_table_id.setter
    def default_route_table_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_route_table_id", value)

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the AWS account that owns the route table.
        """
        return pulumi.get(self, "owner_id")

    @owner_id.setter
    def owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_id", value)

    @property
    @pulumi.getter(name="propagatingVgws")
    def propagating_vgws(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of virtual gateways for propagation.
        """
        return pulumi.get(self, "propagating_vgws")

    @propagating_vgws.setter
    def propagating_vgws(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "propagating_vgws", value)

    @property
    @pulumi.getter
    def routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]]]:
        """
        Set of objects. Detailed below
        """
        return pulumi.get(self, "routes")

    @routes.setter
    def routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultRouteTableRouteArgs']]]]):
        pulumi.set(self, "routes", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider .
        """
        return pulumi.get(self, "tags_all")

    @tags_all.setter
    def tags_all(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags_all", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)


class DefaultRouteTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_route_table_id: Optional[pulumi.Input[str]] = None,
                 propagating_vgws: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultRouteTableRouteArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a resource to manage a default route table of a VPC. This resource can manage the default route table of the default or a non-default VPC.

        > **NOTE:** This is an advanced resource with special caveats. Please read this document in its entirety before using this resource. The `ec2.DefaultRouteTable` resource behaves differently from normal resources. This provider does not _create_ this resource but instead attempts to "adopt" it into management. **Do not** use both `ec2.DefaultRouteTable` to manage a default route table **and** `ec2.MainRouteTableAssociation` with the same VPC due to possible route conflicts. See ec2.MainRouteTableAssociation documentation for more details.

        Every VPC has a default route table that can be managed but not destroyed. When the provider first adopts a default route table, it **immediately removes all defined routes**. It then proceeds to create any routes specified in the configuration. This step is required so that only the routes specified in the configuration exist in the default route table.

        For more information, see the Amazon VPC User Guide on [Route Tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html). For information about managing normal route tables in this provider, see `ec2.RouteTable`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.ec2.DefaultRouteTable("example",
            default_route_table_id=aws_vpc["example"]["default_route_table_id"],
            routes=[
                aws.ec2.DefaultRouteTableRouteArgs(
                    cidr_block="10.0.1.0/24",
                    gateway_id=aws_internet_gateway["example"]["id"],
                ),
                aws.ec2.DefaultRouteTableRouteArgs(
                    ipv6_cidr_block="::/0",
                    egress_only_gateway_id=aws_egress_only_internet_gateway["example"]["id"],
                ),
            ],
            tags={
                "Name": "example",
            })
        ```

        To subsequently remove all managed routes:

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.ec2.DefaultRouteTable("example",
            default_route_table_id=aws_vpc["example"]["default_route_table_id"],
            routes=[],
            tags={
                "Name": "example",
            })
        ```

        ## Import

        Default VPC route tables can be imported using the `vpc_id`, e.g.,

        ```sh
         $ pulumi import aws:ec2/defaultRouteTable:DefaultRouteTable example vpc-33cc44dd
        ```

         [aws-route-tables]http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html#Route_Replacing_Main_Table [tf-route-tables]/docs/providers/aws/r/route_table.html [tf-main-route-table-association]/docs/providers/aws/r/main_route_table_association.html

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_route_table_id: ID of the default route table.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] propagating_vgws: List of virtual gateways for propagation.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultRouteTableRouteArgs']]]] routes: Set of objects. Detailed below
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DefaultRouteTableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage a default route table of a VPC. This resource can manage the default route table of the default or a non-default VPC.

        > **NOTE:** This is an advanced resource with special caveats. Please read this document in its entirety before using this resource. The `ec2.DefaultRouteTable` resource behaves differently from normal resources. This provider does not _create_ this resource but instead attempts to "adopt" it into management. **Do not** use both `ec2.DefaultRouteTable` to manage a default route table **and** `ec2.MainRouteTableAssociation` with the same VPC due to possible route conflicts. See ec2.MainRouteTableAssociation documentation for more details.

        Every VPC has a default route table that can be managed but not destroyed. When the provider first adopts a default route table, it **immediately removes all defined routes**. It then proceeds to create any routes specified in the configuration. This step is required so that only the routes specified in the configuration exist in the default route table.

        For more information, see the Amazon VPC User Guide on [Route Tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html). For information about managing normal route tables in this provider, see `ec2.RouteTable`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.ec2.DefaultRouteTable("example",
            default_route_table_id=aws_vpc["example"]["default_route_table_id"],
            routes=[
                aws.ec2.DefaultRouteTableRouteArgs(
                    cidr_block="10.0.1.0/24",
                    gateway_id=aws_internet_gateway["example"]["id"],
                ),
                aws.ec2.DefaultRouteTableRouteArgs(
                    ipv6_cidr_block="::/0",
                    egress_only_gateway_id=aws_egress_only_internet_gateway["example"]["id"],
                ),
            ],
            tags={
                "Name": "example",
            })
        ```

        To subsequently remove all managed routes:

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.ec2.DefaultRouteTable("example",
            default_route_table_id=aws_vpc["example"]["default_route_table_id"],
            routes=[],
            tags={
                "Name": "example",
            })
        ```

        ## Import

        Default VPC route tables can be imported using the `vpc_id`, e.g.,

        ```sh
         $ pulumi import aws:ec2/defaultRouteTable:DefaultRouteTable example vpc-33cc44dd
        ```

         [aws-route-tables]http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Route_Tables.html#Route_Replacing_Main_Table [tf-route-tables]/docs/providers/aws/r/route_table.html [tf-main-route-table-association]/docs/providers/aws/r/main_route_table_association.html

        :param str resource_name: The name of the resource.
        :param DefaultRouteTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DefaultRouteTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_route_table_id: Optional[pulumi.Input[str]] = None,
                 propagating_vgws: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultRouteTableRouteArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DefaultRouteTableArgs.__new__(DefaultRouteTableArgs)

            if default_route_table_id is None and not opts.urn:
                raise TypeError("Missing required property 'default_route_table_id'")
            __props__.__dict__["default_route_table_id"] = default_route_table_id
            __props__.__dict__["propagating_vgws"] = propagating_vgws
            __props__.__dict__["routes"] = routes
            __props__.__dict__["tags"] = tags
            __props__.__dict__["arn"] = None
            __props__.__dict__["owner_id"] = None
            __props__.__dict__["tags_all"] = None
            __props__.__dict__["vpc_id"] = None
        super(DefaultRouteTable, __self__).__init__(
            'aws:ec2/defaultRouteTable:DefaultRouteTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            default_route_table_id: Optional[pulumi.Input[str]] = None,
            owner_id: Optional[pulumi.Input[str]] = None,
            propagating_vgws: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultRouteTableRouteArgs']]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None) -> 'DefaultRouteTable':
        """
        Get an existing DefaultRouteTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The ARN of the route table.
        :param pulumi.Input[str] default_route_table_id: ID of the default route table.
        :param pulumi.Input[str] owner_id: ID of the AWS account that owns the route table.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] propagating_vgws: List of virtual gateways for propagation.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultRouteTableRouteArgs']]]] routes: Set of objects. Detailed below
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider .
        :param pulumi.Input[str] vpc_id: ID of the VPC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DefaultRouteTableState.__new__(_DefaultRouteTableState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["default_route_table_id"] = default_route_table_id
        __props__.__dict__["owner_id"] = owner_id
        __props__.__dict__["propagating_vgws"] = propagating_vgws
        __props__.__dict__["routes"] = routes
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_all"] = tags_all
        __props__.__dict__["vpc_id"] = vpc_id
        return DefaultRouteTable(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        The ARN of the route table.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="defaultRouteTableId")
    def default_route_table_id(self) -> pulumi.Output[str]:
        """
        ID of the default route table.
        """
        return pulumi.get(self, "default_route_table_id")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> pulumi.Output[str]:
        """
        ID of the AWS account that owns the route table.
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter(name="propagatingVgws")
    def propagating_vgws(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of virtual gateways for propagation.
        """
        return pulumi.get(self, "propagating_vgws")

    @property
    @pulumi.getter
    def routes(self) -> pulumi.Output[Sequence['outputs.DefaultRouteTableRoute']]:
        """
        Set of objects. Detailed below
        """
        return pulumi.get(self, "routes")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> pulumi.Output[Mapping[str, str]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider .
        """
        return pulumi.get(self, "tags_all")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['NetworkProfileArgs', 'NetworkProfile']

@pulumi.input_type
class NetworkProfileArgs:
    def __init__(__self__, *,
                 project_arn: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 downlink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 downlink_delay_ms: Optional[pulumi.Input[int]] = None,
                 downlink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 downlink_loss_percent: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uplink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 uplink_delay_ms: Optional[pulumi.Input[int]] = None,
                 uplink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 uplink_loss_percent: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a NetworkProfile resource.
        :param pulumi.Input[str] project_arn: The ARN of the project for the network profile.
        :param pulumi.Input[str] description: The description of the network profile.
        :param pulumi.Input[int] downlink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] downlink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        :param pulumi.Input[str] name: The name for the network profile.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[str] type: The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        :param pulumi.Input[int] uplink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] uplink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        pulumi.set(__self__, "project_arn", project_arn)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if downlink_bandwidth_bits is not None:
            pulumi.set(__self__, "downlink_bandwidth_bits", downlink_bandwidth_bits)
        if downlink_delay_ms is not None:
            pulumi.set(__self__, "downlink_delay_ms", downlink_delay_ms)
        if downlink_jitter_ms is not None:
            pulumi.set(__self__, "downlink_jitter_ms", downlink_jitter_ms)
        if downlink_loss_percent is not None:
            pulumi.set(__self__, "downlink_loss_percent", downlink_loss_percent)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if uplink_bandwidth_bits is not None:
            pulumi.set(__self__, "uplink_bandwidth_bits", uplink_bandwidth_bits)
        if uplink_delay_ms is not None:
            pulumi.set(__self__, "uplink_delay_ms", uplink_delay_ms)
        if uplink_jitter_ms is not None:
            pulumi.set(__self__, "uplink_jitter_ms", uplink_jitter_ms)
        if uplink_loss_percent is not None:
            pulumi.set(__self__, "uplink_loss_percent", uplink_loss_percent)

    @property
    @pulumi.getter(name="projectArn")
    def project_arn(self) -> pulumi.Input[str]:
        """
        The ARN of the project for the network profile.
        """
        return pulumi.get(self, "project_arn")

    @project_arn.setter
    def project_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_arn", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the network profile.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="downlinkBandwidthBits")
    def downlink_bandwidth_bits(self) -> Optional[pulumi.Input[int]]:
        """
        The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        """
        return pulumi.get(self, "downlink_bandwidth_bits")

    @downlink_bandwidth_bits.setter
    def downlink_bandwidth_bits(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_bandwidth_bits", value)

    @property
    @pulumi.getter(name="downlinkDelayMs")
    def downlink_delay_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "downlink_delay_ms")

    @downlink_delay_ms.setter
    def downlink_delay_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_delay_ms", value)

    @property
    @pulumi.getter(name="downlinkJitterMs")
    def downlink_jitter_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "downlink_jitter_ms")

    @downlink_jitter_ms.setter
    def downlink_jitter_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_jitter_ms", value)

    @property
    @pulumi.getter(name="downlinkLossPercent")
    def downlink_loss_percent(self) -> Optional[pulumi.Input[int]]:
        """
        Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        return pulumi.get(self, "downlink_loss_percent")

    @downlink_loss_percent.setter
    def downlink_loss_percent(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_loss_percent", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for the network profile.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="uplinkBandwidthBits")
    def uplink_bandwidth_bits(self) -> Optional[pulumi.Input[int]]:
        """
        The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        """
        return pulumi.get(self, "uplink_bandwidth_bits")

    @uplink_bandwidth_bits.setter
    def uplink_bandwidth_bits(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_bandwidth_bits", value)

    @property
    @pulumi.getter(name="uplinkDelayMs")
    def uplink_delay_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "uplink_delay_ms")

    @uplink_delay_ms.setter
    def uplink_delay_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_delay_ms", value)

    @property
    @pulumi.getter(name="uplinkJitterMs")
    def uplink_jitter_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "uplink_jitter_ms")

    @uplink_jitter_ms.setter
    def uplink_jitter_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_jitter_ms", value)

    @property
    @pulumi.getter(name="uplinkLossPercent")
    def uplink_loss_percent(self) -> Optional[pulumi.Input[int]]:
        """
        Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        return pulumi.get(self, "uplink_loss_percent")

    @uplink_loss_percent.setter
    def uplink_loss_percent(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_loss_percent", value)


@pulumi.input_type
class _NetworkProfileState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 downlink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 downlink_delay_ms: Optional[pulumi.Input[int]] = None,
                 downlink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 downlink_loss_percent: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_arn: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uplink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 uplink_delay_ms: Optional[pulumi.Input[int]] = None,
                 uplink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 uplink_loss_percent: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering NetworkProfile resources.
        :param pulumi.Input[str] arn: The Amazon Resource Name of this network profile.
        :param pulumi.Input[str] description: The description of the network profile.
        :param pulumi.Input[int] downlink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] downlink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        :param pulumi.Input[str] name: The name for the network profile.
        :param pulumi.Input[str] project_arn: The ARN of the project for the network profile.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block).
        :param pulumi.Input[str] type: The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        :param pulumi.Input[int] uplink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] uplink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if downlink_bandwidth_bits is not None:
            pulumi.set(__self__, "downlink_bandwidth_bits", downlink_bandwidth_bits)
        if downlink_delay_ms is not None:
            pulumi.set(__self__, "downlink_delay_ms", downlink_delay_ms)
        if downlink_jitter_ms is not None:
            pulumi.set(__self__, "downlink_jitter_ms", downlink_jitter_ms)
        if downlink_loss_percent is not None:
            pulumi.set(__self__, "downlink_loss_percent", downlink_loss_percent)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_arn is not None:
            pulumi.set(__self__, "project_arn", project_arn)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_all is not None:
            pulumi.set(__self__, "tags_all", tags_all)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if uplink_bandwidth_bits is not None:
            pulumi.set(__self__, "uplink_bandwidth_bits", uplink_bandwidth_bits)
        if uplink_delay_ms is not None:
            pulumi.set(__self__, "uplink_delay_ms", uplink_delay_ms)
        if uplink_jitter_ms is not None:
            pulumi.set(__self__, "uplink_jitter_ms", uplink_jitter_ms)
        if uplink_loss_percent is not None:
            pulumi.set(__self__, "uplink_loss_percent", uplink_loss_percent)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Amazon Resource Name of this network profile.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the network profile.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="downlinkBandwidthBits")
    def downlink_bandwidth_bits(self) -> Optional[pulumi.Input[int]]:
        """
        The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        """
        return pulumi.get(self, "downlink_bandwidth_bits")

    @downlink_bandwidth_bits.setter
    def downlink_bandwidth_bits(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_bandwidth_bits", value)

    @property
    @pulumi.getter(name="downlinkDelayMs")
    def downlink_delay_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "downlink_delay_ms")

    @downlink_delay_ms.setter
    def downlink_delay_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_delay_ms", value)

    @property
    @pulumi.getter(name="downlinkJitterMs")
    def downlink_jitter_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "downlink_jitter_ms")

    @downlink_jitter_ms.setter
    def downlink_jitter_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_jitter_ms", value)

    @property
    @pulumi.getter(name="downlinkLossPercent")
    def downlink_loss_percent(self) -> Optional[pulumi.Input[int]]:
        """
        Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        return pulumi.get(self, "downlink_loss_percent")

    @downlink_loss_percent.setter
    def downlink_loss_percent(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downlink_loss_percent", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for the network profile.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectArn")
    def project_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the project for the network profile.
        """
        return pulumi.get(self, "project_arn")

    @project_arn.setter
    def project_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_arn", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block).
        """
        return pulumi.get(self, "tags_all")

    @tags_all.setter
    def tags_all(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags_all", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="uplinkBandwidthBits")
    def uplink_bandwidth_bits(self) -> Optional[pulumi.Input[int]]:
        """
        The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        """
        return pulumi.get(self, "uplink_bandwidth_bits")

    @uplink_bandwidth_bits.setter
    def uplink_bandwidth_bits(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_bandwidth_bits", value)

    @property
    @pulumi.getter(name="uplinkDelayMs")
    def uplink_delay_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "uplink_delay_ms")

    @uplink_delay_ms.setter
    def uplink_delay_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_delay_ms", value)

    @property
    @pulumi.getter(name="uplinkJitterMs")
    def uplink_jitter_ms(self) -> Optional[pulumi.Input[int]]:
        """
        Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "uplink_jitter_ms")

    @uplink_jitter_ms.setter
    def uplink_jitter_ms(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_jitter_ms", value)

    @property
    @pulumi.getter(name="uplinkLossPercent")
    def uplink_loss_percent(self) -> Optional[pulumi.Input[int]]:
        """
        Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        return pulumi.get(self, "uplink_loss_percent")

    @uplink_loss_percent.setter
    def uplink_loss_percent(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uplink_loss_percent", value)


class NetworkProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 downlink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 downlink_delay_ms: Optional[pulumi.Input[int]] = None,
                 downlink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 downlink_loss_percent: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_arn: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uplink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 uplink_delay_ms: Optional[pulumi.Input[int]] = None,
                 uplink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 uplink_loss_percent: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a resource to manage AWS Device Farm Network Profiles.
        ∂
        > **NOTE:** AWS currently has limited regional support for Device Farm (e.g., `us-west-2`). See [AWS Device Farm endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/devicefarm.html) for information on supported regions.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_project = aws.devicefarm.Project("exampleProject")
        example_network_profile = aws.devicefarm.NetworkProfile("exampleNetworkProfile", project_arn=example_project.arn)
        ```

        ## Import

        DeviceFarm Network Profiles can be imported by their arn

        ```sh
         $ pulumi import aws:devicefarm/networkProfile:NetworkProfile example arn:aws:devicefarm:us-west-2:123456789012:networkprofile:4fa784c7-ccb4-4dbf-ba4f-02198320daa1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the network profile.
        :param pulumi.Input[int] downlink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] downlink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        :param pulumi.Input[str] name: The name for the network profile.
        :param pulumi.Input[str] project_arn: The ARN of the project for the network profile.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[str] type: The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        :param pulumi.Input[int] uplink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] uplink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage AWS Device Farm Network Profiles.
        ∂
        > **NOTE:** AWS currently has limited regional support for Device Farm (e.g., `us-west-2`). See [AWS Device Farm endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/devicefarm.html) for information on supported regions.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_project = aws.devicefarm.Project("exampleProject")
        example_network_profile = aws.devicefarm.NetworkProfile("exampleNetworkProfile", project_arn=example_project.arn)
        ```

        ## Import

        DeviceFarm Network Profiles can be imported by their arn

        ```sh
         $ pulumi import aws:devicefarm/networkProfile:NetworkProfile example arn:aws:devicefarm:us-west-2:123456789012:networkprofile:4fa784c7-ccb4-4dbf-ba4f-02198320daa1
        ```

        :param str resource_name: The name of the resource.
        :param NetworkProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 downlink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 downlink_delay_ms: Optional[pulumi.Input[int]] = None,
                 downlink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 downlink_loss_percent: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_arn: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uplink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
                 uplink_delay_ms: Optional[pulumi.Input[int]] = None,
                 uplink_jitter_ms: Optional[pulumi.Input[int]] = None,
                 uplink_loss_percent: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkProfileArgs.__new__(NetworkProfileArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["downlink_bandwidth_bits"] = downlink_bandwidth_bits
            __props__.__dict__["downlink_delay_ms"] = downlink_delay_ms
            __props__.__dict__["downlink_jitter_ms"] = downlink_jitter_ms
            __props__.__dict__["downlink_loss_percent"] = downlink_loss_percent
            __props__.__dict__["name"] = name
            if project_arn is None and not opts.urn:
                raise TypeError("Missing required property 'project_arn'")
            __props__.__dict__["project_arn"] = project_arn
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
            __props__.__dict__["uplink_bandwidth_bits"] = uplink_bandwidth_bits
            __props__.__dict__["uplink_delay_ms"] = uplink_delay_ms
            __props__.__dict__["uplink_jitter_ms"] = uplink_jitter_ms
            __props__.__dict__["uplink_loss_percent"] = uplink_loss_percent
            __props__.__dict__["arn"] = None
            __props__.__dict__["tags_all"] = None
        super(NetworkProfile, __self__).__init__(
            'aws:devicefarm/networkProfile:NetworkProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            downlink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
            downlink_delay_ms: Optional[pulumi.Input[int]] = None,
            downlink_jitter_ms: Optional[pulumi.Input[int]] = None,
            downlink_loss_percent: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project_arn: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            type: Optional[pulumi.Input[str]] = None,
            uplink_bandwidth_bits: Optional[pulumi.Input[int]] = None,
            uplink_delay_ms: Optional[pulumi.Input[int]] = None,
            uplink_jitter_ms: Optional[pulumi.Input[int]] = None,
            uplink_loss_percent: Optional[pulumi.Input[int]] = None) -> 'NetworkProfile':
        """
        Get an existing NetworkProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The Amazon Resource Name of this network profile.
        :param pulumi.Input[str] description: The description of the network profile.
        :param pulumi.Input[int] downlink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] downlink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] downlink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        :param pulumi.Input[str] name: The name for the network profile.
        :param pulumi.Input[str] project_arn: The ARN of the project for the network profile.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block).
        :param pulumi.Input[str] type: The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        :param pulumi.Input[int] uplink_bandwidth_bits: The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        :param pulumi.Input[int] uplink_delay_ms: Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_jitter_ms: Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        :param pulumi.Input[int] uplink_loss_percent: Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkProfileState.__new__(_NetworkProfileState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["description"] = description
        __props__.__dict__["downlink_bandwidth_bits"] = downlink_bandwidth_bits
        __props__.__dict__["downlink_delay_ms"] = downlink_delay_ms
        __props__.__dict__["downlink_jitter_ms"] = downlink_jitter_ms
        __props__.__dict__["downlink_loss_percent"] = downlink_loss_percent
        __props__.__dict__["name"] = name
        __props__.__dict__["project_arn"] = project_arn
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_all"] = tags_all
        __props__.__dict__["type"] = type
        __props__.__dict__["uplink_bandwidth_bits"] = uplink_bandwidth_bits
        __props__.__dict__["uplink_delay_ms"] = uplink_delay_ms
        __props__.__dict__["uplink_jitter_ms"] = uplink_jitter_ms
        __props__.__dict__["uplink_loss_percent"] = uplink_loss_percent
        return NetworkProfile(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        The Amazon Resource Name of this network profile.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the network profile.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="downlinkBandwidthBits")
    def downlink_bandwidth_bits(self) -> pulumi.Output[Optional[int]]:
        """
        The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        """
        return pulumi.get(self, "downlink_bandwidth_bits")

    @property
    @pulumi.getter(name="downlinkDelayMs")
    def downlink_delay_ms(self) -> pulumi.Output[Optional[int]]:
        """
        Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "downlink_delay_ms")

    @property
    @pulumi.getter(name="downlinkJitterMs")
    def downlink_jitter_ms(self) -> pulumi.Output[Optional[int]]:
        """
        Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "downlink_jitter_ms")

    @property
    @pulumi.getter(name="downlinkLossPercent")
    def downlink_loss_percent(self) -> pulumi.Output[Optional[int]]:
        """
        Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        return pulumi.get(self, "downlink_loss_percent")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name for the network profile.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectArn")
    def project_arn(self) -> pulumi.Output[str]:
        """
        The ARN of the project for the network profile.
        """
        return pulumi.get(self, "project_arn")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A map of tags to assign to the resource. If configured with a provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block) present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> pulumi.Output[Mapping[str, str]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider [`default_tags` configuration block](https://www.terraform.io/docs/providers/aws/index.html#default_tags-configuration-block).
        """
        return pulumi.get(self, "tags_all")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of network profile to create. Valid values are listed are `PRIVATE` and `CURATED`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="uplinkBandwidthBits")
    def uplink_bandwidth_bits(self) -> pulumi.Output[Optional[int]]:
        """
        The data throughput rate in bits per second, as an integer from `0` to `104857600`. Default value is `104857600`.
        """
        return pulumi.get(self, "uplink_bandwidth_bits")

    @property
    @pulumi.getter(name="uplinkDelayMs")
    def uplink_delay_ms(self) -> pulumi.Output[Optional[int]]:
        """
        Delay time for all packets to destination in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "uplink_delay_ms")

    @property
    @pulumi.getter(name="uplinkJitterMs")
    def uplink_jitter_ms(self) -> pulumi.Output[Optional[int]]:
        """
        Time variation in the delay of received packets in milliseconds as an integer from `0` to `2000`.
        """
        return pulumi.get(self, "uplink_jitter_ms")

    @property
    @pulumi.getter(name="uplinkLossPercent")
    def uplink_loss_percent(self) -> pulumi.Output[Optional[int]]:
        """
        Proportion of received packets that fail to arrive from `0` to `100` percent.
        """
        return pulumi.get(self, "uplink_loss_percent")

